﻿using System.Windows;
using System.Threading;
using WpfAudioPlayer.Views;
using WpfAudioPlayer.ViewModels;

namespace WpfAudioPlayer
{
	/// <summary>
	/// App.xaml の相互作用ロジック
	/// </summary>
	public partial class App : Application
	{
		/// <summary>
		/// アプリケーションが終了する時のイベントです。
		/// </summary>
		/// <param name="e">イベント データ。</param>
		protected override void OnExit( ExitEventArgs e )
		{
			if( App.Mutex == null ) { return; }

			// ミューテックスの解放
			App.Mutex.ReleaseMutex();
			App.Mutex.Close();
			App.Mutex = null;
		}

		/// <summary>
		/// アプリケーションが開始される時のイベントです。
		/// </summary>
		/// <param name="e">イベント データ。</param>
		protected override void OnStartup( StartupEventArgs e )
		{
			// 多重起動チェック
			App.Mutex = new Mutex( false, App.MutexName );
			if( !App.Mutex.WaitOne( 0, false ) )
			{
				App.Mutex.Close();
				App.Mutex = null;
				this.Shutdown();
				return;
			}

			var window = new MainWindow();
			window.DataContext = new MainWindowViewModel( window );
			window.Show();
		}

		/// <summary>
		/// 多重起動を防止するためのミューテックス名。
		/// </summary>
		private const string MutexName = "WpfAudioPlayer-{767BD2D0-8B61-4ad5-AA72-5691B194B59D}";

		/// <summary>
		/// 多重起動を防止する為のミューテックス。
		/// </summary>
		private static Mutex Mutex;
	}
}
