﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Un4seen.Bass;
using Un4seen.Bass.AddOn.Fx;
using WpfAudioPlayer.Models;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// イコライザーの View と Model を仲介するクラスです。
	/// </summary>
	class EqualizerViewModel : ViewModelBase
	{
		/// <summary>
		/// ストリームにイコライザーを割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public void Attach( int stream )
		{
			this._equalizer.Attach( stream );
		}

		/// <summary>
		/// 32 Hz のゲインを取得または設定します。
		/// </summary>
		public float Gain32
		{
			get
			{
				return this._equalizer.Gain32;
			}
			set
			{
				this._equalizer.Gain32 = value;
				this.NotifyPropertyChanged( "Gain32" );
			}
		}

		/// <summary>
		/// 64 Hz のゲインを取得または設定します。
		/// </summary>
		public float Gain64
		{
			get
			{
				return this._equalizer.Gain64;
			}
			set
			{
				this._equalizer.Gain64 = value;
				this.NotifyPropertyChanged( "Gain64" );
			}
		}
		
		/// <summary>
		/// 125 Hz のゲインを取得または設定します。
		/// </summary>
		public float Gain125
		{
			get
			{
				return this._equalizer.Gain125;
			}
			set
			{
				this._equalizer.Gain125 = value;
				this.NotifyPropertyChanged( "Gain125" );
			}
		}
		
		/// <summary>
		/// 250 Hz のゲインを取得または設定します。
		/// </summary>
		public float Gain250
		{
			get
			{
				return this._equalizer.Gain250;
			}
			set
			{
				this._equalizer.Gain250 = value;
				this.NotifyPropertyChanged( "Gain250" );
			}
		}
		
		/// <summary>
		/// 500 Hz のゲインを取得または設定します。
		/// </summary>
		public float Gain500
		{
			get
			{
				return this._equalizer.Gain500;
			}
			set
			{
				this._equalizer.Gain500 = value;
				this.NotifyPropertyChanged( "Gain500" );
			}
		}
		
		/// <summary>
		/// 1 KHz のゲインを取得または設定します。
		/// </summary>
		public float Gain1K
		{
			get
			{
				return this._equalizer.Gain1K;
			}
			set
			{
				this._equalizer.Gain1K = value;
				this.NotifyPropertyChanged( "Gain1K" );
			}
		}
		
		/// <summary>
		/// 2 KHz のゲインを取得または設定します。
		/// </summary>
		public float Gain2K
		{
			get
			{
				return this._equalizer.Gain2K;
			}
			set
			{
				this._equalizer.Gain2K = value;
				this.NotifyPropertyChanged( "Gain2K" );
			}
		}
	
		/// <summary>
		/// 4 KHz のゲインを取得または設定します。
		/// </summary>
		public float Gain4K
		{
			get
			{
				return this._equalizer.Gain4K;
			}
			set
			{
				this._equalizer.Gain4K = value;
				this.NotifyPropertyChanged( "Gain4K" );
			}
		}

		/// <summary>
		/// 8 KHz のゲインを取得または設定します。
		/// </summary>
		public float Gain8K
		{
			get
			{
				return this._equalizer.Gain8K;
			}
			set
			{
				this._equalizer.Gain8K = value;
				this.NotifyPropertyChanged( "Gain8K" );
			}
		}
	
		/// <summary>
		/// 16 KHz のゲインを取得または設定します。
		/// </summary>
		public float Gain16K
		{
			get
			{
				return this._equalizer.Gain16K;
			}
			set
			{
				this._equalizer.Gain16K = value;
				this.NotifyPropertyChanged( "Gain16K" );
			}
		}

		/// <summary>
		/// イコライザ。
		/// </summary>
		private AudioEqualizer _equalizer = new AudioEqualizer();
	}
}
